/***********************************************************************************************************************
 *
 * OpenBlueSky - NetBeans Platform Enhancements
 * Copyright (C) 2006-2012 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://openbluesky.java.net
 * SCM: https://bitbucket.org/tidalwave/openbluesky-src
 *
 **********************************************************************************************************************/
package it.tidalwave.hierarchy.node;

import org.openide.util.Lookup;
import java.util.Collection;
import org.openide.nodes.Node;
import it.tidalwave.netbeans.util.Locator;
import it.tidalwave.util.NotFoundException;
import it.tidalwave.netbeans.nodes.role.RootNodeProvider;
import it.tidalwave.hierarchy.HViewManager;
import it.tidalwave.netbeans.capabilitiesprovider.CapabilitiesProvider;
import it.tidalwave.netbeans.util.test.Resettable;
import static it.tidalwave.hierarchy.HViewManager.HViewManager;
import org.junit.Test;
import static org.junit.Assert.*;
import static org.hamcrest.CoreMatchers.*;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public class HViewManagerNodeDelegateFactoryProviderTest
  {
    @Test
    public void mustBeRegisteredInMETAINF()
      {
        Lookup.getDefault().lookupAll(CapabilitiesProvider.class); // FIXME: since 4-Mar-2011 it's needed for the test..
        Locator.find(HViewManagerRootNodeProviderProvider.class);
      }

    @Test
    public void mustCreateCorrectNode()
      throws NotFoundException
      {
        final HViewManager hViewManager = Locator.find(HViewManager);
        hViewManager.as(Resettable.class).reset();
        final HViewManagerRootNodeProviderProvider capabilityProvider = new HViewManagerRootNodeProviderProvider();
        final Collection<? extends Object> capabilities = capabilityProvider.createCapabilities(hViewManager);
        assertThat(capabilities, is(notNullValue()));
        assertThat(capabilities.size(), is(1));
        final RootNodeProvider rootNodeProvider = (RootNodeProvider)capabilities.iterator().next();
        final Node node = rootNodeProvider.getRootNode();
        assertThat(node, is(instanceOf(HViewManagerNode.class)));
        assertThat(node.getLookup().lookup(HViewManager.class), is(sameInstance(hViewManager)));
      }
  }