/***********************************************************************************************************************
 *
 * OpenBlueSky - NetBeans Platform Enhancements
 * Copyright (C) 2006-2012 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://openbluesky.java.net
 * SCM: https://bitbucket.org/tidalwave/openbluesky-src
 *
 **********************************************************************************************************************/
package it.tidalwave.hierarchy.node;

import java.util.Collection;
import org.openide.nodes.Node;
import it.tidalwave.netbeans.util.Locator;
import it.tidalwave.netbeans.nodes.role.NodeDelegateFactory;
import it.tidalwave.hierarchy.HView;
import it.tidalwave.hierarchy.HViewManager;
import it.tidalwave.netbeans.util.test.Resettable;
import static it.tidalwave.hierarchy.HViewManager.HViewManager;
import org.junit.Test;
import static org.junit.Assert.*;
import static org.hamcrest.CoreMatchers.*;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public class HViewNodeDelegateFactoryProviderTest
  {
    @Test
    public void mustBeRegisteredInMETAINF()
      {
        Locator.find(HViewNodeDelegateFactoryProvider.class);
      }

    @Test
    public void mustCreateCorrectNode()
      {
        final HViewManager hViewManager = Locator.find(HViewManager);
        hViewManager.as(Resettable.class).reset();
        final HView hView = hViewManager.createView().withDisplayName("view").build();
        
        final HViewNodeDelegateFactoryProvider capabilityProvider = new HViewNodeDelegateFactoryProvider();
        final Collection<? extends Object> capabilities = capabilityProvider.createCapabilities(hView);
        assertThat(capabilities, is(notNullValue()));
        assertThat(capabilities.size(), is(1));
        final NodeDelegateFactory nodeFactory = (NodeDelegateFactory)capabilities.iterator().next();
        final Node node = nodeFactory.createNodeDelegate();
        assertThat(node, is(instanceOf(HViewNode.class)));
        assertThat(node.getLookup().lookup(HView.class), is(sameInstance(hView)));
      }
  }